@@ -16,20 +16,27 @@
 #
 # Authors: Tiago Cogumbreiro <cogumbreiro@users.sf.net>
 
-import gtkutil, gtk, operations, os, os.path, gaw
+import gtk
+import os
+import os.path
+import tempfile
 
+# Local imports
+import operations
+import gaw
 import constants
+import gtkutil
 
-from components import SimpleComponent
+from components import Component
 from operations import MapProxy, OperationListener, OperationsQueue
 from operations import CallableOperation
 from mastering import AudioMastering, GtkMusicList, MusicListGateway
 from mastering import ErrorTrapper
-from recording import RecordMusicList, RecordingMedia
 
 from serpentine.common import *
+from gettext import gettext as _
 
-class GladeComponent (SimpleComponent):
+class GladeComponent (Component):
 
     def _setup_glade (self, g):
         """This method is called when the SerpentineWindow object is created."""
@@ -107,7 +114,6 @@ class PlaylistComponent (FileDialogComponent):
         playlist = self.file_dlg.get_uri()
         self.parent.music_list_widget.music_list_gateway.add_files ([playlist]).start ()
         self.parent.clear_files ()
-import tempfile
 
 class SavePlaylistComponent (GladeComponent):
     def _setup_glade (self, g):
@@ -122,7 +128,7 @@ class SavePlaylistComponent (GladeComponent):
         self.file_dlg.set_title ("")
         self.file_dlg.set_transient_for (self.parent)
         app = self.parent.application
-        app.save_playlist.listeners.append (self)
+        app.savePlaylist.listeners.append (self)
         self.__sync = True
     
     def on_registred (self, factory, extension, description):
@@ -133,14 +139,14 @@ class SavePlaylistComponent (GladeComponent):
             
         if evt.id == operations.SUCCESSFUL:
             gtkutil.dialog_warn (
-                "Playlist Saved",
-                "Playlist was saved successfully.",
+                _("Playlist Saved"),
+                _("Playlist was saved successfully."),
                 win
             )
         else:
             gtkutil.dialog_error (
-                "Playlist Not Saved",
-                "There was an error while saving the playlist.",
+                _("Playlist Not Saved"),
+                _("There was an error while saving the playlist."),
                 win
             )
         
@@ -155,7 +161,7 @@ class SavePlaylistComponent (GladeComponent):
             self.file_dlg.remove_filter (f)
         
         # Now fill the real filters
-        for f in app.save_playlist.file_filters:
+        for f in app.savePlaylist.file_filters:
             self.file_dlg.add_filter (f)
         
         # Sync is complete
@@ -171,10 +177,10 @@ class SavePlaylistComponent (GladeComponent):
             filename = self.file_dlg.get_filename ()
             basename = os.path.basename (filename)
             if os.path.exists (filename) and gtkutil.dialog_ok_cancel (
-                "Replace existing file",
-                "A file named <i>%s</i> already exists. "\
-                "Do you want to replace it with the one "\
-                "you are saving?" % basename,
+                _("Replace existing file"),
+                _("A file named <i>%s</i> already exists. "
+                "Do you want to replace it with the one "
+                "you are saving?") % basename,
                 win
             ) != gtk.RESPONSE_OK:
                 
@@ -183,12 +189,12 @@ class SavePlaylistComponent (GladeComponent):
                 return
                 
             try:
-                oper = app.save_playlist.save (filename)
+                oper = app.savePlaylist.save (filename)
             except SerpentineNotSupportedError:
                 gtkutil.dialog_error (
-                    "Unsupported Format",
-                    "The playlist format you used (by the file extension) is " \
-                    "currently not supported.",
+                    _("Unsupported Format"),
+                    _("The playlist format you used (by the file extension) is "
+                    "currently not supported."),
                     win
                 )
             oper.listeners.append (self)
@@ -288,7 +294,7 @@ class ToolbarComponent (GladeComponent):
             
     style = property (style)
 
-class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, SimpleComponent):
+class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Component):
     # TODO: finish up implementing an Operation
     components = (
         AddFileComponent,
@@ -300,7 +306,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
     def __init__ (self, application):
         gtk.Window.__init__ (self, gtk.WINDOW_TOPLEVEL)
         operations.Operation.__init__ (self)
-        SimpleComponent.__init__ (self, application)
+        Component.__init__ (self, application)
             
         self.__application = application
         self.__masterer = AudioMastering ()
@@ -321,11 +327,19 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
         self.add (g.get_widget ("main_window_container"))
         self.set_title ("Serpentine")
         self.set_default_size (450, 350)
+        self.set_icon_name ("gnome-dev-cdrom-audio")
         
         
         # record button
-        g.get_widget("burn").connect ("clicked", self.__on_write_files)
-        g.get_widget ("write_to_disc_mni").connect ("activate", self.__on_write_files)
+        # setup record button
+        self.__write_to_disc = MapProxy (dict(
+            button = g.get_widget ("write_to_disc"),
+            menu   = g.get_widget ("write_to_disc_mni")
+        ))
+        
+        self.__write_to_disc.set_sensitive (False)
+        self.__write_to_disc["button"].connect ("clicked", self.__on_write_files)
+        self.__write_to_disc["menu"].connect ("activate", self.__on_write_files)
         
         # masterer widget
         box = self.get_child()
@@ -336,22 +350,18 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
         g.get_widget ("preferences_mni").connect ("activate", self.__on_preferences)
         
         # setup remove buttons
-        self.remove = MapProxy ({'menu': g.get_widget ("remove_mni"),
-                                 'button': g.get_widget ("remove")})
+        self.remove = MapProxy ({"menu": g.get_widget ("remove_mni"),
+                                 "button": g.get_widget ("remove")})
 
         self.remove["menu"].connect ("activate", self.__on_remove_file)
         self.remove["button"].connect ("clicked", self.__on_remove_file)
         self.remove.set_sensitive (False)
         
-        # setup record button
-        self.__on_write_files = g.get_widget ("burn")
-        self.__on_write_files.set_sensitive (False)
-        
         # setup clear buttons
-        self.clear = MapProxy ({'menu': g.get_widget ("clear_mni"),
-                                'button': g.get_widget ("clear")})
-        self.clear['button'].connect ("clicked", self.clear_files)
-        self.clear['menu'].connect ("activate", self.clear_files)
+        self.clear = MapProxy ({"menu": g.get_widget ("clear_mni"),
+                                "button": g.get_widget ("clear")})
+        self.clear["button"].connect ("clicked", self.clear_files)
+        self.clear["menu"].connect ("activate", self.clear_files)
         self.clear.set_sensitive (False)
         
         # setup quit menu item
@@ -365,9 +375,14 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
         self.on_contents_changed()
         
         if self.__application.preferences.drive is None:
-            gtkutil.dialog_warn ("No recording drive found", "No recording drive found on your system, therefore some of Serpentine's functionalities will be disabled.", self)
+            gtkutil.dialog_warn (
+                _("No recording drive found"),
+                _("No recording drive found on your system, therefore some of "
+                  "Serpentine's functionalities will be disabled."),
+                self
+            )
             g.get_widget ("preferences_mni").set_sensitive (False)
-            self.__on_write_files.set_sensitive (False)
+            self.__write_to_disc.set_sensitive (False)
     
         # Load internal XSPF playlist
         self.__load_playlist()
@@ -391,7 +406,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
         #TODO: move it to SerpentineApplication ?
         """Private method for loading the internal playlist."""
         try:
-            self.__application.preferences.load_playlist (self.music_list_widget.source)
+            self.__application.preferences.loadPlaylist (self.music_list_widget.source)
         except:
             import traceback
             traceback.print_exc()
@@ -404,7 +419,7 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
         self.clear.set_sensitive (is_sensitive)
         # Only set it sentitive if the drive is available and is not recording
         if self.__application.preferences.drive is not None:
-            self.__on_write_files.set_sensitive (is_sensitive)
+            self.__write_to_disc.set_sensitive (is_sensitive)
 
     def __on_remove_file (self, *args):
         self.music_list_widget.remove_selected()
@@ -437,28 +452,30 @@ class SerpentineWindow (gtk.Window, OperationListener, operations.Operation, Sim
             show_prefs = False
             
             if err.error_id == SerpentineCacheError.INVALID:
-                title = "Cache directory location unavailable"
+                title = _("Cache directory location unavailable")
                 show_prefs = True
                 
             elif err.error_id == SerpentineCacheError.NO_SPACE:
-                title = "Not enough space on cache directory"
+                title = _("Not enough space on cache directory")
             
             gtkutil.dialog_warn (title, err.error_message)
             return
 
         # TODO: move this to recording module?
         if self.music_list_widget.source.total_duration > self.music_list_widget.disc_size:
-            title = "Do you want to overburn your disc?"
-            msg = "You are about to record a media disc in overburn mode. " \
-                  "This may not work on all drives and shouldn't give you " \
-                  "more then a couple of minutes."
-            btn = "Write to Disc (Overburning)"
+            title = _("Do you want to overburn your disc?")
+            msg = _("You are about to record a media disc in overburn mode. "
+                    "This may not work on all drives and shouldn't give you "
+                    "more then a couple of minutes.")
+            btn = _("Write to Disc (Overburning)")
             self.__application.preferences.overburn = True
         else:
-            title = "Do you want to record your musics?"
-            msg = "You are about to record a media disc. " \
-                  "Canceling a writing operation will make your disc unusable."
-            btn = "Write to Disc"
+            title = _("Do you want to record your music?")
+            msg = _("You are about to record a media disc. "
+                    "Canceling a writing operation will make "
+                    "your disc unusable.")
+                    
+            btn = _("Write to Disc")
             self.__application.preferences.overburn = False
         
         if gtkutil.dialog_ok_cancel (title, msg, self, btn) != gtk.RESPONSE_OK:
